#
# spec file for package patchelf
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           patchelf
Version:        0.12
Release:        1.4
Summary:        A utility for patching ELF binaries
License:        GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://nixos.org/patchelf.html
Source:         https://github.com/NixOS/patchelf/releases/download/%{version}/patchelf-%{version}.tar.bz2
BuildRequires:  gcc-c++

%description
PatchELF is a simple utility for modifing existing ELF executables and
libraries.  It can change the dynamic loader ("ELF interpreter") of
executables and change the RPATH of executables and libraries.

%prep
%setup -q -n %{name}-0.12.20200827.8d3a16e

%build
%configure
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
%make_install
rm -v %{buildroot}%{_datadir}/doc/patchelf/README.md

%files
%doc README.md
%license COPYING
%{_bindir}/patchelf
%{_mandir}/man1/patchelf.1%{?ext_man}

%changelog
* Fri Sep 11 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.12:
  * skip overwriting r(un)path data when old_rpath = new_rpath.
  * patchelf: Check ELF endianness before writing new runpath
  * use stable_sort to maintain relative order for equal elemnts
  * add --clear-symbol-version
  * Improve the default section alignment choice
  * Some const-correctness and C++11 auto
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.11:
  * More modern C++ has avoided a memory leak
  * force-rpath is now consistently used
  * new --output flag
* Tue Aug 27 2019 Martin Pluskal <mpluskal@suse.com>
- Changelog and packaging cleanups
- Fix download url
* Mon Aug 26 2019 Mikhail Terekhov <termim@gmail.com>
- Update to version 0.10
  * remove no-rpath-prebuilt.patch - applied upstream
  * Lots of bug fixes see https://github.com/NixOS/patchelf/commits/master
* Thu Nov 15 2018 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
- Install license file
* Fri Apr  1 2016 dvaleev@suse.com
- Enable exluded architectures.
  Fixed by debian patch no-rpath-prebuilt.patch
* Sun Mar 20 2016 mpluskal@suse.com
- Update to version 0.9
  * Lots of new features
- Add aarch64 to list of excluded architectures
* Thu Aug 13 2015 normand@linux.vnet.ibm.com
- exclude ppc64le as already done for ppc/ppc64 (4 tests FAIL)
    set-interpreter-long.sh
    set-rpath.sh
    big-dynstr.sh
    set-rpath-library.sh
  Same exclude on fedora as per bug 627370
  https://bugzilla.redhat.com/show_bug.cgi?id=627370
* Sat Aug  2 2014 idonmez@suse.com
- Update to version 0.8
  * No changelog upstream
* Tue Jul  3 2012 dvaleev@suse.com
- exclude ppc and ppc64. Tests are failed
* Thu Jun 21 2012 adrian@suse.de
- initial packaging of patchelf version 0.6
  required for accelerated cross build package
